# helsingborgalarm
![GitHub](https://img.shields.io/github/license/jonasbjork/helsingborgalarm?style=for-the-badge)
![Twitter Follow](https://img.shields.io/twitter/follow/jonasbjork?style=for-the-badge&logo=twitter)

This package will download and format all current alarms presented at helsingborg.se homepage.

## Installation
```python
pip install helsingborgalarm
```

## Usage
To download and show current published alarms:
```python
import helsingborgalarm

h = HelsingborgAlarm()
h.print_larms()
```

## Help

No help yet.